"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const node_fetch_1 = __importDefault(require("node-fetch"));
class Server {
    getData;
    startCooldownTimer;
    cooldown = 0;
    lastData;
    constructor(ip, key) {
        if (!ip)
            throw new Error('ip is required');
        if (!key)
            throw new Error('key is required');
        this.startCooldownTimer = (cooldown) => new Promise(resolve => {
            setTimeout(() => {
                this.cooldown = 0;
                resolve();
            }, cooldown);
        });
        this.getData = (options = {
            lastOnline: false,
            players: false,
            playerList: false,
            info: false,
            pastebin: false,
            version: false,
            flags: false,
            nicknames: false,
            online: false
        }) => new Promise(async (resolve, reject) => {
            if (this.cooldown !== 0) {
                if (this.lastData)
                    return resolve(this.lastData);
                else
                    return reject('Ratelimit exceeded');
            }
            let baseLink = `https://api.scpslgame.com/serverinfo.php/?ip=${ip}&key=${key}`;
            if (options.lastOnline)
                baseLink += '&lastOnline=true';
            if (options.players)
                baseLink += '&players=true';
            if (options.playerList)
                baseLink += '&playerList=true';
            if (options.info)
                baseLink += '&info=true';
            if (options.pastebin)
                baseLink += '&pastebin=true';
            if (options.version)
                baseLink += '&version=true';
            if (options.flags)
                baseLink += '&flags=true';
            if (options.nicknames)
                baseLink += '&nicknames=true';
            if (options.online)
                baseLink += '&online=true';
            const res = await (0, node_fetch_1.default)(baseLink);
            const data = await res.json();
            if (data.Error)
                return reject(data.Error);
            if (options.info) {
                data.Servers.map(server => {
                    server.Info = Buffer.from(server.Info, 'base64').toString('utf-8');
                });
            }
            this.cooldown = data.Cooldown;
            this.lastData = data;
            this.startCooldownTimer(data.Cooldown);
            resolve(data);
        });
    }
}
exports.default = Server;
